@@ -22,6 +22,7 @@ Config.define('CONNECT_TIMEOUT_IN_SECONDS', 20, _('Number of seconds a connectio
 Config.define('REQUEST_TIMEOUT_IN_SECONDS', 60, _('Number of seconds a request can take.'), 'Worker')
 
 Config.define('HOLMES_API_URL', 'http://localhost:2368', ('URL that Worker will communicate with API'), 'Worker')
+Config.define('HOLMES_WEB_URL', 'http://local.holmes.com:9000', _('URL of the client side application of Holmes'), 'Web')
 
 Config.define('LOG_LEVEL', 'ERROR', 'Default log level', 'Logging')
 Config.define('LOG_FORMAT', '%(asctime)s:%(levelname)s %(module)s - %(message)s',
@@ -72,8 +73,6 @@ Config.define('MAX_IMAGE_ALT_SIZE', 70,
               _('Image alt attributes longer than 70 characters may be truncated in the results'),
               'Image Alt Attribute Validator')
 
-Config.define('ORIGIN', '*', _('Access Control Allow Origin header value'), 'Web')
-
 Config.define('HTTP_PROXY_HOST', None, _('HTTP Proxy Host to use'), 'Web')
 Config.define('HTTP_PROXY_PORT', None, _('HTTP Proxy Port to use'), 'Web')
 
@@ -85,6 +84,7 @@ Config.define('COMMIT_ON_REQUEST_END', True, _('Commit on request end'), 'DB')
 Config.define('MATERIAL_GIRL_REDISPORT', 7575, _('Redis port'), 'Redis')
 Config.define('MATERIAL_GIRL_REDISHOST', 'localhost', _('Redis host'), 'Redis')
 Config.define('MATERIAL_GIRL_REDISPASS', None, _('Redis password in case of auth'), 'Redis')
+Config.define('MATERIAL_GIRL_LOAD_ON_CACHEMISS', True, _('Load from database on cache miss'), 'Materializer')
 
 Config.define('REQUIRED_META_TAGS', [], _('List of required meta tags'), 'Meta tag Validator')
 
@@ -103,6 +103,8 @@ Config.define('ELASTIC_SEARCH_HOST', 'localhost', _('ElasticSearch host'), 'Elas
 Config.define('ELASTIC_SEARCH_PORT', 9200, _('ElasticSearch port'), 'ElasticSearchProvider')
 Config.define('ELASTIC_SEARCH_INDEX', 'holmes', _('ElasticSearch index name'), 'ElasticSearchProvider')
 
+Config.define('ELASTIC_SEARCH_MAX_RETRIES', 3, _('ElasticSearch max number of retries'), 'ElasticSearchProvider')
+
 # SENTRY ERROR HANDLER
 Config.define('USE_SENTRY', False, _('If set to true errors will be sent to sentry.'), 'Sentry')
 Config.define('SENTRY_DSN_URL', '', _('URL to use as sentry DSN.'), 'Sentry')
@@ -139,6 +141,17 @@ materials_grace_period_in_seconds = {
 }
 Config.define('MATERIALS_GRACE_PERIOD_IN_SECONDS', materials_grace_period_in_seconds, _('Grace period times for materials'), 'material')
 
+materials_lock_timeout_in_seconds = {
+    'domains_details': 3 * materials_grace_period_in_seconds['domains_details'] / 4,
+    'violation_count_for_domains': 3 * materials_grace_period_in_seconds['violation_count_for_domains'] / 4,
+    'violation_count_by_category_for_domains': 3 * materials_grace_period_in_seconds['violation_count_by_category_for_domains'] / 4,
+    'top_violations_in_category_for_domains': 3 * materials_grace_period_in_seconds['top_violations_in_category_for_domains'] / 4,
+    'blacklist_domain_count': 3 * materials_grace_period_in_seconds['blacklist_domain_count'] / 4,
+    'most_common_violations': 3 * materials_grace_period_in_seconds['most_common_violations'] / 4,
+    'failed_responses_count': 3 * materials_grace_period_in_seconds['failed_responses_count'] / 4,
+}
+Config.define('MATERIALS_LOCK_TIMEOUT_IN_SECONDS', materials_lock_timeout_in_seconds, _('Lock timeouts for materials'), 'material')
+
 Config.define('DEFAULT_PAGE_SCORE', 1, _('Page Score for pages that the user includes through the UI'), 'General')
 Config.define('PAGE_SCORE_TAX_RATE', 0.1, _('Default tax rate for scoring pages.'), 'General')
 Config.define('MAX_PAGE_SCORE', 15000000, _('Maximum score of page'), 'General')
@@ -167,3 +180,6 @@ Config.define('EVENT_BUS_THROTTLING_MESSAGE_TYPE', throttling_message_type, _('T
 Config.define('SQLALCHEMY_AUTO_FLUSH', True, _('Defines whether auto-flush should be used in sqlalchemy'))
 
 Config.define('DOMAINS_VIOLATIONS_PREFS_EXPIRATION_IN_SECONDS', HOUR, _('Expiration in seconds for domains violations prefs.'), 'Cache')
+
+Config.define('SECRET_KEY', 'set-a-secret-key', _('Secret key to use in JSON Web Token generation'), 'Sessions')
+Config.define('SESSION_EXPIRATION', HOUR, _('Time for Session expiration in seconds'), 'Sessions')
