@@ -27,21 +27,24 @@ def configure_materials(girl, db, config):
         'domains_details',
         partial(Domain.get_domains_details, db),
         config.MATERIALS_EXPIRATION_IN_SECONDS['domains_details'],
-        config.MATERIALS_GRACE_PERIOD_IN_SECONDS['domains_details']
+        config.MATERIALS_GRACE_PERIOD_IN_SECONDS['domains_details'],
+        config.MATERIALS_LOCK_TIMEOUT_IN_SECONDS['domains_details']
     )
 
     girl.add_material(
         'violation_count_for_domains',
         partial(MaterialConveyor.get_violation_count_for_domains, db),
         config.MATERIALS_EXPIRATION_IN_SECONDS['violation_count_for_domains'],
-        config.MATERIALS_GRACE_PERIOD_IN_SECONDS['violation_count_for_domains']
+        config.MATERIALS_GRACE_PERIOD_IN_SECONDS['violation_count_for_domains'],
+        config.MATERIALS_LOCK_TIMEOUT_IN_SECONDS['violation_count_for_domains']
     )
 
     girl.add_material(
         'violation_count_by_category_for_domains',
         partial(Violation.get_group_by_category_id_for_all_domains, db),
         config.MATERIALS_EXPIRATION_IN_SECONDS['violation_count_by_category_for_domains'],
-        config.MATERIALS_GRACE_PERIOD_IN_SECONDS['violation_count_by_category_for_domains']
+        config.MATERIALS_GRACE_PERIOD_IN_SECONDS['violation_count_by_category_for_domains'],
+        config.MATERIALS_LOCK_TIMEOUT_IN_SECONDS['violation_count_by_category_for_domains']
     )
 
     girl.add_material(
@@ -52,14 +55,16 @@ def configure_materials(girl, db, config):
             config.get('TOP_CATEGORY_VIOLATIONS_SAMPLE_LIMIT')
         ),
         config.MATERIALS_EXPIRATION_IN_SECONDS['top_violations_in_category_for_domains'],
-        config.MATERIALS_GRACE_PERIOD_IN_SECONDS['top_violations_in_category_for_domains']
+        config.MATERIALS_GRACE_PERIOD_IN_SECONDS['top_violations_in_category_for_domains'],
+        config.MATERIALS_LOCK_TIMEOUT_IN_SECONDS['top_violations_in_category_for_domains']
     )
 
     girl.add_material(
         'blacklist_domain_count',
         partial(MaterialConveyor.get_blacklist_domain_count, db),
         config.MATERIALS_EXPIRATION_IN_SECONDS['blacklist_domain_count'],
-        config.MATERIALS_GRACE_PERIOD_IN_SECONDS['blacklist_domain_count']
+        config.MATERIALS_GRACE_PERIOD_IN_SECONDS['blacklist_domain_count'],
+        config.MATERIALS_LOCK_TIMEOUT_IN_SECONDS['blacklist_domain_count']
     )
 
     girl.add_material(
@@ -70,7 +75,8 @@ def configure_materials(girl, db, config):
             config.get('MOST_COMMON_VIOLATIONS_SAMPLE_LIMIT')
         ),
         config.MATERIALS_EXPIRATION_IN_SECONDS['most_common_violations'],
-        config.MATERIALS_GRACE_PERIOD_IN_SECONDS['most_common_violations']
+        config.MATERIALS_GRACE_PERIOD_IN_SECONDS['most_common_violations'],
+        config.MATERIALS_LOCK_TIMEOUT_IN_SECONDS['most_common_violations']
     )
 
     girl.add_material(
@@ -81,7 +87,8 @@ def configure_materials(girl, db, config):
             config.get('MAX_REQUESTS_FOR_FAILED_RESPONSES')
         ),
         config.MATERIALS_EXPIRATION_IN_SECONDS['failed_responses_count'],
-        config.MATERIALS_GRACE_PERIOD_IN_SECONDS['failed_responses_count']
+        config.MATERIALS_GRACE_PERIOD_IN_SECONDS['failed_responses_count'],
+        config.MATERIALS_LOCK_TIMEOUT_IN_SECONDS['failed_responses_count']
     )
 
 
